@@ -50,11 +50,6 @@ class Shimehari(_Kouzi):
     debug = None
     testing = None
 
-    debugLogFormat = ('-' * 80 + '\n' +
-        '%(levelname)s in %(module)s [%(pathname)s:%(lineno)d]:\n' +
-        '%(message)s\n' +
-        '-' * 80)
-
     requestClass = Request
     responseClass = Response
 
@@ -79,7 +74,7 @@ class Shimehari(_Kouzi):
         'SECRET_KEY':'_secret_shimehari'
     }
 
-    #tempalte options
+    templateOptions = {}
 
     sessionStore = SessionStore()
 
@@ -89,7 +84,7 @@ class Shimehari(_Kouzi):
                  staticURL=None, staticFolder='static',
                  appFolder='app', controllerFolder='controllers', 
                  viewFolder='views', assetsFolder='assets',
-                 instancePath=None, isRelativeConfig=False):
+                 instancePath=None, isRelativeConfig=False,templateOptions={}):
 
         _Kouzi.__init__(self, importName, appFolder=appFolder, 
                         controllerFolder=controllerFolder, viewFolder=viewFolder)
@@ -133,9 +128,8 @@ class Shimehari(_Kouzi):
         self.sessionKey = self.config['SECRET_KEY']
         self.useXSendFile = self.config['USE_X_SENDFILE']
 
-        #ふむ
-        self.templater = getTemplater(self, self.config['TEMPLATE_ENGINE'])
-
+        self.templateOptions = templateOptions
+        
         if self.config['AUTO_SETUP']:
             self.setup()
 
@@ -160,13 +154,6 @@ class Shimehari(_Kouzi):
         return self.debug
 
 
-
-    #@property
-    #def useXSendFile(self):
-    #    return self.config['USE_X_SENDFILE']
-
-
-
     @property
     def logger(self):
         if self._logger and self._logger.name == self.loggerName:
@@ -175,7 +162,7 @@ class Shimehari(_Kouzi):
             if self._logger and self._logger.name == self.loggerName:
                 return self._logger
             from shimehari.logging import createLogger
-            self._logger = rv = createLogger(self)
+            self._logger = rv = createLogger(self.loggerName)
             return rv
 
 
@@ -364,12 +351,18 @@ class Shimehari(_Kouzi):
             sys.exit(0)
         try:
             apps = __import__(self.appFolder)
+            self.setupTemplater()
             self.setupBindController()
             self.setupBindRouter()
         except (ImportError, AttributeError):
             raise ShimehariSetupError('Application directory is invalid')
 
 
+    def setupTemplater(self):
+        try:
+            self.templater = getTemplater(self, self.config['TEMPLATE_ENGINE'],templateOptions=self.templateOptions)
+        except Exception, e:
+            raise ShimehariSetupError('setup template engine was failed... \n%s' % e)
 
     u"""-----------------------------
         ::pkg:: Shimehari.app
@@ -382,7 +375,7 @@ class Shimehari(_Kouzi):
     def setupBindController(self):
         self.controllerPath = os.path.join(self.appPath, self.controllerFolder)
         if not os.path.isdir(self.controllerPath):
-            raise ShimehariSetupError('Controller in the specified directory does not exist.')
+            raise ShimehariSetupError('Controller in the specified directory does not exist. %s' % self.controllerPath)
 
         try:
             ctrlDir = self.appFolder + '.' + self.controllerFolder
