@@ -38,7 +38,9 @@ ConfigManager.addConfigs([
 
         'AUTO_SETUP':True,
 
-        'TEPMLATE_ENGINE':'jinja2',
+        'CONTROLLER_AUTO_NAMESPACE':True,
+
+        'TEMPLATE_ENGINE':'jinja2',
 
         'SECRET_KEY':'_secret_shimehari',
 
@@ -46,6 +48,35 @@ ConfigManager.addConfigs([
 
         'PRESERVE_CONTEXT_ON_EXCEPTION':None,
 
-        'PERMANENT_SESSION_LIFETIME':timedelta(days=31)
+        'PERMANENT_SESSION_LIFETIME':timedelta(days=31),
+
+        #キャッシュ
+        'CACHE_STORE':None,
+
+        'CACHE_DEFAULT_TIMEOUT': 300,
+
+        'CACHE_THRESHOLD':500,
+
+        'CACHE_KEY_PREFIX':None,
+
+        'CACHE_DIR':None,
+
+        'CACHE_OPTIONS':None,
+        
+        'CACHE_ARGS':[],
+
+        'LOG_FILE_OUTPUT':False,
+        
+        'LOG_FILE_ROTATE':False,
+
+        'LOG_ROTATE_MAX_BITE':(5*1024*1024),
+        
+        'LOG_ROTATE_COUNT':5,
+
+        'LOG_FILE_DIRECTORY':'%s/log',
+
+        'LOG_DEBUG_FORMAT':%s,
+
+        'LOG_OUTPUT_FORMAT':%s
     })
 ])
\ No newline at end of file
